| Title: | A standard reporting protocol for conservation planning |
|---|---|
| Description: | This repository contains the environment and shiny code underlying the reporting protocol. |
| Authors: | Martin Jung [cre, aut] |
| Maintainer: | Martin Jung <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.6 |
| Built: | 2026-05-25 07:01:15 UTC |
| Source: | https://github.com/iiasa/ODPSCP |
Run the Shiny Application
run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |